#' Coda glottalization annotations
#'
#' Annotations for postvocalic /t/ and /p/ coda segments in the Buckeye Corpus,
#' including hand-corrected transcriptions for glottal replacement and phrasal
#' creak. One row per coda segment.
#'
#' If you use this data in academic publications or presentations, please cite
#' the following publications:
#'
#' Seyfarth, S. & Garellek, M. (2020). Physical and phonological causes of coda
#' /t/ glottalization in the mainstream American English of central Ohio.
#' Laboratory Phonology: Journal of the Association for Laboratory Phonology,
#' 11(1), 24. DOI: http://doi.org/10.5334/labphon.213
#'
#' Pitt, M.A., Dilley, L., Johnson, K., Kiesling, S., Raymond, W., Hume, E. and
#' Fosler-Lussier, E. (2007) Buckeye Corpus of Conversational Speech (2nd
#' release) [www.buckeyecorpus.osu.edu] Columbus, OH: Department of Psychology,
#' Ohio State University (Distributor).
#'
#' The pseudo-ARPABET transcription system used for some of the columns is
#' described in the Buckeye Corpus manual.
#'
#' @format A data frame with 12,451 rows and 40 variables:
#' \describe{
#'   \item{track}{Name of the Buckeye Corpus file that contains this coda.}
#'   \item{coda_timestamp}{Timestamp of this coda in the Buckeye Corpus.}
#'   \item{word_timestamp}{Timestamp of the word in the Buckeye Corpus that
#'   contains this coda.}
#'   \item{filename}{Unique filename assigned to this token. Used for VoiceSauce
#'   and TextGrids.}
#'   \item{speaker}{Code-name in the Buckeye Corpus for the speaker who produced
#'   this coda.}
#'   \item{sex}{Sex of the speaker. F for female and M for male.}
#'   \item{age}{Age of the speaker. O for old (over 40) and Y for young (under
#'   30 or 40).}
#'   \item{word}{Word that contains this coda.}
#'   \item{coda_phonemic}{Dictionary transcription of the coda segment.}
#'   \item{coda_phonetic}{Close phonetic transcription of the coda segment, with
#'   Unicode transcriptions. Re-transcribed using the criteria described in
#'   Seyfarth & Garellek.}
#'   \item{coda_phonetic_uncorrected}{Close phonetic transcription of
#'   the coda segment, with pseudo-ARPABET transcriptions. Transcribed by the
#'   Buckeye Corpus annotators.}
#'   \item{coda_duration}{Duration of the coda, in seconds.}
#'   \item{vowel_phonemic}{Dictionary transcription of the nucleus vowel
#'   preceding this coda, with pseudo-ARPABET transcriptions.}
#'   \item{vowel_phonetic}{Close phonetic transcription of the nucleus vowel,
#'   with pseudo-ARPABET transcriptions. Transcribed by the Buckeye Corpus
#'   annotators.}
#'   \item{vowel_duration}{Duration of the nucleus vowel, in seconds.}
#'   \item{word_phonemic}{Dictionary transcription of the word that contains
#'   this coda, with pseudo-ARPABET transcriptions. Segments in the
#'   transcription are separated by underscores.}
#'   \item{word_phonetic}{close phonetic transcription of the word that contains
#'   this coda, with pseudo-ARPABET transcriptions. Transcribed by the Buckeye
#'   Corpus annotators. Segments in the transcription are separated by
#'   underscores.}
#'   \item{onset}{TRUE if the syllable that contains this coda has an onset.}
#'   \item{stress}{Lexical stress assigned to the syllable that contains this
#'   coda, roughly based on the CMU Pronouncing Dictionary distributed with
#'   NLTK. Stress for all function words words not in the CMU Pronouncing
#'   Dictionary were added manually.}
#'   \item{syllable_number}{1 if the coda is in the first syllable in the word,
#'   2 if the coda is in the second syllable in the word, etc.}
#'   \item{syllable_total}{Total number of syllables in the word.}
#'   \item{word_position}{'medial' if the coda is word-medial or 'final' if the
#'   coda is word-final.}
#'   \item{phrase_position}{'medial' if the word that contains this coda is
#'   phrase-medial, or 'final' if the word is phrase-final. Transcribed using
#'   the criteria described in Seyfarth & Garellek.}
#'   \item{utterance_position}{'medial' if the word that contains this coda is
#'   utterance-medial, or 'final' if the word is utterance-final. Words are
#'   considered to be utterance-final if they were phrase-final and were
#'   followed by a silence or other non-sound entry (IVER, LAUGH, NOISE, SIL,
#'   VOCNOIS, E_TRANS) in the original corpus annotations.}
#'   \item{following_phonemic}{Dictionary transcription of the segment
#'   following the coda, with pseudo-ARPABET transcriptions. Non-sound entries
#'   (IVER, LAUGH, NOISE, SIL, VOCNOISE, E_TRANS) are listed as 'none'.}
#'   \item{following_phonetic}{Close phonetic transcription of the segment
#'   following the coda, with pseudo-ARPABET transcriptions. Transcribed by
#'   the Buckeye Corpus annotators. Non-sound entries (IVER, LAUGH, NOISE, SIL,
#'   VOCNOIS, E_TRANS) are listed as 'none'.}
#'   \item{following_phonemic_uncorrected}{Dictionary transcription of the
#'   segment following the coda, with pseudo-ARPABET transcriptions.}
#'   \item{following_phonetic_uncorrected}{Close phonetic transcription of the
#'   segment following the coda, with pseudo-ARPABET transcriptions.
#'   Transcribed by the Buckeye Corpus annotators.}
#'   \item{preceding_word}{Word that precedes the word that contains this coda.}
#'   \item{following_word}{Word that follows the word that contains this coda.}
#'   \item{following_stress}{Lexical stress assigned to the syllable following
#'   the coda, roughly based on the CMU Pronouncing Dictionary distributed with
#'   NLTK. Stress for all function words words not in the CMU Pronouncing
#'   Dictionary were added manually.}
#'   \item{phrasal_creak}{TRUE if this coda occurs during a stretch of phrasal
#'   creak. Transcribed using the criteria described in Seyfarth & Garellek.}
#'   \item{phrasal_creak_uncorrected}{TRUE if this coda occurs during a stretch
#'   of speech that was marked as creaky voice by the Buckeye Corpus annotators,
#'   and the stretch of creaky voice was at least twice as long as the
#'   preceding nucleus vowel.}
#'   \item{speech_rate}{Speech rate of the utterance that contains this coda, in
#'   syllables per second. An utterance is defined as a stretch of speech
#'   delimited by pauses of 500 milliseconds or greater.}
#'   \item{closure_duration}{Duration of the closure portion of this coda.
#'   Hand-annotated but not all codas were annotated for closure duration.
#'   Codas that were not annotated for the closure duration are marked as NA.}
#'   \item{release}{TRUE if this coda was audibly and visibly released.
#'   Hand-annotated but not all codas were annotated for release. Codas that
#'   were not annotated for release are marked as NA.}
#'   \item{vowel_dB}{Mean intensity of the vowel, in decibels.}
#'   \item{burst_dB}{Mean intensity of the release burst, in decibels.}
#'   \item{alignment_corrected}{TRUE if the segmentation boundaries were altered
#'   from the boundaries provided by the Buckeye Corpus annotators}
#'   \item{comments}{Comments provided by research assistants during
#'   hand-annotation done with Seyfarth & Garellek.}
#' }
"codas"

#' Deleted coda metadata
#'
#' Metadata for deleted postvocalic /t/ and /p/ coda segments in the Buckeye
#' Corpus. One row per coda segment.
#'
#' If you use this data in academic publications or presentations, please cite
#' the following publication:
#'
#' Pitt, M.A., Dilley, L., Johnson, K., Kiesling, S., Raymond, W., Hume, E. and
#' Fosler-Lussier, E. (2007) Buckeye Corpus of Conversational Speech (2nd
#' release) [www.buckeyecorpus.osu.edu] Columbus, OH: Department of Psychology,
#' Ohio State University (Distributor).
#'
#' The pseudo-ARPABET transcription system used for some of the columns is
#' described in the Buckeye Corpus manual.
#'
#' @format A data frame with 1,769 rows and 20 variables:
#' \describe{
#'   \item{track}{Name of the Buckeye Corpus file that contains this coda.}
#'   \item{word_timestamp}{Timestamp of the word in the Buckeye Corpus that
#'   contains this coda.}
#'   \item{filename}{Unique filename assigned to this token. Used for VoiceSauce
#'   and TextGrids.}
#'   \item{speaker}{Code-name in the Buckeye Corpus for the speaker who produced
#'   this coda.}
#'   \item{sex}{Sex of the speaker. F for female and M for male.}
#'   \item{age}{Age of the speaker. O for old (over 40) and Y for young (under
#'   30 or 40).}
#'   \item{word}{Word that contains this coda.}
#'   \item{coda_phonemic}{Dictionary transcription of the coda segment.}
#'   \item{vowel_phonemic}{Dictionary transcription of the nucleus vowel
#'   preceding this coda, with pseudo-ARPABET transcriptions.}
#'   \item{word_phonemic}{Dictionary transcription of the word that contains
#'   this coda, with pseudo-ARPABET transcriptions. Segments in the
#'   transcription are separated by underscores.}
#'   \item{word_phonetic}{close phonetic transcription of the word that contains
#'   this coda, with pseudo-ARPABET transcriptions. Transcribed by the Buckeye
#'   Corpus annotators. Segments in the transcription are separated by
#'   underscores.}
#'   \item{onset}{TRUE if the syllable that contains this coda has an onset.}
#'   \item{syllable_number}{1 if the coda is in the first syllable in the word,
#'   2 if the coda is in the second syllable in the word, etc.}
#'   \item{syllable_total}{Total number of syllables in the word.}
#'   \item{word_position}{'medial' if the coda is word-medial or 'final' if the
#'   coda is word-final.}
#'   \item{following_phonemic}{Dictionary transcription of the segment
#'   following the coda, with pseudo-ARPABET transcriptions. Non-sound entries
#'   (IVER, LAUGH, NOISE, SIL, VOCNOISE, E_TRANS) are listed as 'none'.}
#'   \item{following_phonemic_uncorrected}{Dictionary transcription of the
#'   segment following the coda, with pseudo-ARPABET transcriptions.}
#'   \item{preceding_word}{Word that precedes the word that contains this coda.}
#'   \item{following_word}{Word that follows the word that contains this coda.}
#'   \item{phrasal_creak_uncorrected}{TRUE if this coda occurs during a stretch
#'   of speech that was marked as creaky voice by the Buckeye Corpus annotators,
#'   and the stretch of creaky voice was at least twice as long as the
#'   preceding nucleus vowel.}
#' }
"deleted_codas"

#' Consonant segment features
#'
#'
#' @format A data frame with 24 rows and 4 variables:
#' \describe{
#'   \item{consonant}{Pseudo-ARPABET consonant transcription, using the
#'   transcription conventions described in the Buckeye Corpus manual.}
#'   \item{voicing}{Voicing of the consonant}
#'   \item{place}{Place of articulation of the consonant}
#'   \item{manner}{Manner of articulation of the consonant}
#' }
"consonant_features"

#' Vowel segment features
#'
#'
#' @format A data frame with 28 rows and 6 variables:
#' \describe{
#'   \item{vowel}{Pseudo-ARPABET vowel transcription, using the
#'   transcription conventions described in the Buckeye Corpus manual.}
#'   \item{height}{Vowel height, either 'low', 'mid', 'or 'high'.}
#'   \item{backness}{Vowel backness, either 'front', 'central', or 'back'.}
#'   \item{rounding}{Vowel rounding, either 'unrounded' or 'rounded'.}
#'   \item{diphthong}{Whether the vowel is a diphthong or not, either
#'   'monophthong' or 'diphthong'.}
#'   \item{nasal}{Whether the vowel is nasalized or not, either 'oral' or
#'   'nasal'.}
#' }
"vowel_features"

#' Pitch tracks for nucleus vowels followed by /t, p/ codas
#'
#' This dataframe contains the millisecond-by-millisecond pitch tracks for the
#' vowel preceding each coda in the \code{codas} dataframe, as measured by
#' VoiceSauce.
#'
#' If you use this data, please cite the papers listed in the description of
#' \code{codas} as well as the following paper:
#'
#' Shue, Y.-L., Keating, P., Vicenik, C., & Yu, K. (2011). VoiceSauce: A program
#' for voice analysis. Proceedings of ICPhS XVII, 1846--1849.
#'
#' @format A data frame with 1,567,059 rows and 8 variables:
#' \describe{
#'   \item{filename}{Unique filename assigned to this token. Used for VoiceSauce
#'   and TextGrids. This corresponds to the \code{filename} column in the
#'   \code{codas} dataframe.}
#'   \item{speaker}{Code-name in the Buckeye Corpus for the speaker who produced
#'   this vowel.}
#'   \item{word}{Word that contains this vowel.}
#'   \item{track}{Name of the Buckeye Corpus file that contains this vowel.}
#'   \item{word_beg}{Timestamp of the onset of this token in the Buckeye
#'   Corpus. This does not correspond to the \code{word_timestamp} column in the
#'   \code{codas} dataframe. This column is the onset of the word (and the
#'   offset of the previous word), but the \code{word_timestamp} column in the
#'   \code{codas} dataframe is the offset of this word.}
#'   \item{vowel_phonetic}{Close phonetic transcription of the nucleus vowel,
#'   with pseudo-ARPABET transcriptions. Transcribed by the Buckeye Corpus
#'   annotators. This corresponds to the \code{vowel_phonetic} column in the
#'   \code{codas} dataframe.}
#'   \item{t_ms}{Time in milliseconds, starting from the onset of the nucleus
#'   vowel.}
#'   \item{strF0}{Fundamental frequency of the voice, in Hz, as measured by
#'   STRAIGHT (Kawahara et al., 1998).}
#' }
#' @source \url{http://www.phonetics.ucla.edu/voiceproject/voice.html}
"vowels_voicesauce_pitch"

#' Summary VoiceSauce measurements for nucleus vowels followed by /t, p/ codas
#'
#' This dataframe contains measurements at three timepoints within the vowel
#' preceding each coda in the \code{codas} dataframe, as measured by VoiceSauce.
#'
#' If you use this data, please cite the papers listed in the description of
#' \code{codas} as well as the following papers:
#'
#' Vicenik, C., Lin, S., Keating, P., & Shue, Y-.L. (2019). Online documentation
#' for VoiceSauce. Available at
#' http://www.phonetics.ucla.edu/voicesauce/documentation/index.html.
#'
#' Shue, Y.-L., Keating, P., Vicenik, C., & Yu, K. (2011). VoiceSauce: A program
#' for voice analysis. Proceedings of ICPhS XVII, 1846--1849.
#'
#' @format A data frame with 41,001 rows and 51 variables:
#' \describe{
#'   \item{filename}{Unique filename assigned to this token. Used for VoiceSauce
#'   and TextGrids. This corresponds to the \code{filename} column in the
#'   \code{codas} dataframe.}
#'   \item{vowel_phonetic}{Close phonetic transcription of the nucleus vowel,
#'   with pseudo-ARPABET transcriptions. Transcribed by the Buckeye Corpus
#'   annotators. This corresponds to the \code{vowel_phonetic} column in the
#'   \code{codas} dataframe.}
#'   \item{vowel_duration_vs}{Duration of the nucleus vowel, in milliseconds.}
#'   \item{timepoint}{Timepoint of this measurement within the nucleus vowel. A
#'   1 means that this row contains the measurements for the first third of the
#'   vowel. A 2 means that this row contains the measurements for the middle
#'   third of the vowel. A 3 means that this row contains the measurements for
#'   the final third of the vowel, which is adjacent to the coda segment.}
#'   \item{strF0}{Fundamental frequency of the voice, in Hz, as measured by
#'   STRAIGHT (Kawahara et al., 1998).}
#'   \item{sF0}{Fundamental frequency of the voice, in Hz, as measured by
#'   Snack.}
#'   \item{shrF0}{Fundamental frequency of the voice, in Hz, as measured using
#'   the subharmonic-to-harmonic ratio method (Sun 2002).}
#'   \item{sF1}{Frequency of the first formant, in Hz, as measured by Snack.}
#'   \item{sB1}{Bandwidth of the first formant, in Hz, as measured by Snack.}
#'   \item{sF2}{Frequency of the second formant, in Hz, as measured by Snack.}
#'   \item{sB2}{Bandwidth of the second formant, in Hz, as measured by Snack.}
#'   \item{sF3}{Frequency of the third formant, in Hz, as measured by Snack.}
#'   \item{sB3}{Bandwidth of the third formant, in Hz, as measured by Snack.}
#'   \item{sF4}{Frequency of the fourth formant, in Hz, as measured by Snack.}
#'   \item{sB4}{Bandwidth of the fourth formant, in Hz, as measured by Snack.}
#'   \item{H1u}{Amplitude of the first harmonic of the voice.}
#'   \item{H1c}{Amplitude of the first harmonic of the voice. Corrected for the
#'   formant filter based on Iseli & Alwan (2004, 2006, 2007).}
#'   \item{H2u}{Amplitude of the second harmonic of the voice.}
#'   \item{H2c}{Amplitude of the second harmonic of the voice. Corrected for the
#'   formant filter.}
#'   \item{H4u}{Amplitude of the third harmonic of the voice.}
#'   \item{H4c}{Amplitude of the fourth harmonic of the voice. Corrected for the
#'   formant filter.}
#'   \item{H2Ku}{Amplitude of the harmonic closest to 2 kHz, in decibels.}
#'   \item{H2Kc}{Amplitude of the harmonic closest to 2 kHz, in decibels.
#'   Corrected for the formant filter.}
#'   \item{H5Ku}{Amplitude of the harmonic closest to 5 kHz, in decibels.}
#'   \item{A1u}{Amplitude of the harmonic closest to the first formant peak
#'   frequency, in decibels.}
#'   \item{A1c}{Amplitude of the harmonic closest to the first formant peak
#'   frequency, in decibels. Corrected for the formant filter.}
#'   \item{A2u}{Amplitude of the harmonic closest to the second formant peak
#'   frequency, in decibels.}
#'   \item{A2c}{Amplitude of the harmonic closest to the second formant peak
#'   frequency, in decibels. Corrected for the formant filter.}
#'   \item{A3u}{Amplitude of the harmonic closest to the third formant peak
#'   frequency, in decibels.}
#'   \item{A3c}{Amplitude of the harmonic closest to the third formant peak
#'   frequency, in decibels. Corrected for the formant filter.}
#'   \item{H1H2u}{Difference between H1 and H2, in decibels.}
#'   \item{H1H2c}{Difference between H1 and H2, in decibels. Corrected for the
#'   formant filter.}
#'   \item{H2H4u}{Difference between H2 and H4, in decibels.}
#'   \item{H2H4c}{Difference between H2 and H4, in decibels. Corrected for the
#'   formant filter.}
#'   \item{H1A1u}{Difference between H1 and A1, in decibels.}
#'   \item{H1A1c}{Difference between H1 and A1, in decibels. Corrected for the
#'   formant filter.}
#'   \item{H1A2u}{Difference between H1 and A2, in decibels.}
#'   \item{H1A2c}{Difference between H1 and A2, in decibels. Corrected for the
#'   formant filter.}
#'   \item{H1A3u}{Difference between H1 and A3, in decibels.}
#'   \item{H1A3c}{Difference between H1 and A3, in decibels. Corrected for the
#'   formant filter.}
#'   \item{H42Ku}{Difference between H4 and H2K, in decibels.}
#'   \item{H42Kc}{Difference between H4 and H2K, in decibels. Corrected for the
#'   formant filter.}
#'   \item{H2KH5Ku}{Difference between H2K and H5K, in decibels.}
#'   \item{H2KH5Kc}{Difference between H2K and H5K, in decibels. Corrected for
#'   the formant filter.}
#'   \item{Energy}{Root mean square energy.}
#'   \item{HNR05}{Harmonics-to-noise ratio between 0-500 Hz.}
#'   \item{HNR15}{Harmonics-to-noise ratio between 0-1500 Hz.}
#'   \item{HNR25}{Harmonics-to-noise ratio between 0-2500 Hz.}
#'   \item{HNR35}{Harmonics-to-noise ratio between 0-3500 Hz.}
#'   \item{CPP}{Cepstral peak prominence, in decibels.}
#'   \item{SHR}{Amplitude ratio between subharmonics and harmonics (Sun 2002).}
#' }
#' @source \url{http://www.phonetics.ucla.edu/voiceproject/voice.html}
"vowels_voicesauce"

#' Pitch tracks for rimes containing /t, p/ codas
#'
#' This dataframe contains the millisecond-by-millisecond pitch tracks for the
#' rime of each token in the \code{codas} dataframe, as measured by
#' VoiceSauce. That is, these measurements contain pitch tracks that span across
#' both the nucleus vowel and any portion of the coda segment with a
#' measurable pitch.
#'
#' If you use this data, please cite the papers listed in the description of
#' \code{codas} as well as the following paper:
#'
#' Shue, Y.-L., Keating, P., Vicenik, C., & Yu, K. (2011). VoiceSauce: A program
#' for voice analysis. Proceedings of ICPhS XVII, 1846--1849.
#'
#' @format A data frame with 2,292,217 rows and 9 variables:
#' \describe{
#'   \item{filename}{Unique filename assigned to this token. Used for VoiceSauce
#'   and TextGrids. This corresponds to the \code{filename} column in the
#'   \code{codas} dataframe.}
#'   \item{speaker}{Code-name in the Buckeye Corpus for the speaker who produced
#'   this vowel.}
#'   \item{word}{Word that contains this vowel.}
#'   \item{track}{Name of the Buckeye Corpus file that contains this vowel.}
#'   \item{word_beg}{Timestamp of the onset of this token in the Buckeye
#'   Corpus. This does not correspond to the \code{word_timestamp} column in the
#'   \code{codas} dataframe. This column is the onset of the word (and the
#'   offset of the previous word), but the \code{word_timestamp} column in the
#'   \code{codas} dataframe is the offset of this word.}
#'   \item{vowel_phonetic}{Close phonetic transcription of the nucleus vowel,
#'   with pseudo-ARPABET transcriptions. Transcribed by the Buckeye Corpus
#'   annotators.}
#'   \item{coda_phonetic_uncorrected}{Close phonetic transcription of
#'   the coda segment, with pseudo-ARPABET transcriptions. Transcribed by the
#'   Buckeye Corpus annotators.}
#'   \item{t_ms}{Time in milliseconds, starting from the onset of the nucleus
#'   vowel.}
#'   \item{strF0}{Fundamental frequency of the voice, in Hz, as measured by
#'   STRAIGHT (Kawahara et al., 1998).}
#' }
#' @source \url{http://www.phonetics.ucla.edu/voiceproject/voice.html}
"rimes_voicesauce_pitch"

#' Summary VoiceSauce measurements for rimes containing /t, p/ codas
#'
#' This dataframe contains measurements at three timepoints within the rime of
#' each token in the \code{codas} dataframe, as measured by VoiceSauce. That is,
#' these measurements span across both the nucleus vowel and any portion of the
#' coda segment with a measurable pitch.
#'
#' If you use this data, please cite the papers listed in the description of
#' \code{codas} as well as the following papers:
#'
#' Vicenik, C., Lin, S., Keating, P., & Shue, Y-.L. (2019). Online documentation
#' for VoiceSauce. Available at
#' http://www.phonetics.ucla.edu/voicesauce/documentation/index.html.
#'
#' Shue, Y.-L., Keating, P., Vicenik, C., & Yu, K. (2011). VoiceSauce: A program
#' for voice analysis. Proceedings of ICPhS XVII, 1846--1849.
#'
#' @format A data frame with 41,010 rows and 52 variables:
#' \describe{
#'   \item{filename}{Unique filename assigned to this token. Used for VoiceSauce
#'   and TextGrids. This corresponds to the \code{filename} column in the
#'   \code{codas} dataframe.}
#'   \item{vowel_phonetic}{Close phonetic transcription of the nucleus vowel,
#'   with pseudo-ARPABET transcriptions. Transcribed by the Buckeye Corpus
#'   annotators. This corresponds to the \code{vowel_phonetic} column in the
#'   \code{codas} dataframe.}
#'   \item{coda_phonetic_uncorrected}{Close phonetic transcription of
#'   the coda segment, with pseudo-ARPABET transcriptions. Transcribed by the
#'   Buckeye Corpus annotators.}
#'   \item{rime_duration_vs}{Duration of the rime (vowel plus coda), in
#'   milliseconds.}
#'   \item{timepoint}{Timepoint of this measurement within the rime. A 1 means
#'   that this row contains the measurements for the first third of the rime,
#'   which is most likely entirely within the nucleus vowel. A 2 means that this
#'   row contains the measurements for the middle third of the rime, which may
#'   span part of the nucleus vowel and part of the coda. A 3 means that this
#'   row contains the measurements for the final third of the rime, which
#'   usually includes most of the measurable portion of the coda.}
#'   \item{strF0}{Fundamental frequency of the voice, in Hz, as measured by
#'   STRAIGHT (Kawahara et al., 1998).}
#'   \item{sF0}{Fundamental frequency of the voice, in Hz, as measured by
#'   Snack.}
#'   \item{shrF0}{Fundamental frequency of the voice, in Hz, as measured using
#'   the subharmonic-to-harmonic ratio method (Sun 2002).}
#'   \item{sF1}{Frequency of the first formant, in Hz, as measured by Snack.}
#'   \item{sB1}{Bandwidth of the first formant, in Hz, as measured by Snack.}
#'   \item{sF2}{Frequency of the second formant, in Hz, as measured by Snack.}
#'   \item{sB2}{Bandwidth of the second formant, in Hz, as measured by Snack.}
#'   \item{sF3}{Frequency of the third formant, in Hz, as measured by Snack.}
#'   \item{sB3}{Bandwidth of the third formant, in Hz, as measured by Snack.}
#'   \item{sF4}{Frequency of the fourth formant, in Hz, as measured by Snack.}
#'   \item{sB4}{Bandwidth of the fourth formant, in Hz, as measured by Snack.}
#'   \item{H1u}{Amplitude of the first harmonic of the voice.}
#'   \item{H1c}{Amplitude of the first harmonic of the voice. Corrected for the
#'   formant filter based on Iseli & Alwan (2004, 2006, 2007).}
#'   \item{H2u}{Amplitude of the second harmonic of the voice.}
#'   \item{H2c}{Amplitude of the second harmonic of the voice. Corrected for the
#'   formant filter.}
#'   \item{H4u}{Amplitude of the third harmonic of the voice.}
#'   \item{H4c}{Amplitude of the fourth harmonic of the voice. Corrected for the
#'   formant filter.}
#'   \item{H2Ku}{Amplitude of the harmonic closest to 2 kHz, in decibels.}
#'   \item{H2Kc}{Amplitude of the harmonic closest to 2 kHz, in decibels.
#'   Corrected for the formant filter.}
#'   \item{H5Ku}{Amplitude of the harmonic closest to 5 kHz, in decibels.}
#'   \item{A1u}{Amplitude of the harmonic closest to the first formant peak
#'   frequency, in decibels.}
#'   \item{A1c}{Amplitude of the harmonic closest to the first formant peak
#'   frequency, in decibels. Corrected for the formant filter.}
#'   \item{A2u}{Amplitude of the harmonic closest to the second formant peak
#'   frequency, in decibels.}
#'   \item{A2c}{Amplitude of the harmonic closest to the second formant peak
#'   frequency, in decibels. Corrected for the formant filter.}
#'   \item{A3u}{Amplitude of the harmonic closest to the third formant peak
#'   frequency, in decibels.}
#'   \item{A3c}{Amplitude of the harmonic closest to the third formant peak
#'   frequency, in decibels. Corrected for the formant filter.}
#'   \item{H1H2u}{Difference between H1 and H2, in decibels.}
#'   \item{H1H2c}{Difference between H1 and H2, in decibels. Corrected for the
#'   formant filter.}
#'   \item{H2H4u}{Difference between H2 and H4, in decibels.}
#'   \item{H2H4c}{Difference between H2 and H4, in decibels. Corrected for the
#'   formant filter.}
#'   \item{H1A1u}{Difference between H1 and A1, in decibels.}
#'   \item{H1A1c}{Difference between H1 and A1, in decibels. Corrected for the
#'   formant filter.}
#'   \item{H1A2u}{Difference between H1 and A2, in decibels.}
#'   \item{H1A2c}{Difference between H1 and A2, in decibels. Corrected for the
#'   formant filter.}
#'   \item{H1A3u}{Difference between H1 and A3, in decibels.}
#'   \item{H1A3c}{Difference between H1 and A3, in decibels. Corrected for the
#'   formant filter.}
#'   \item{H42Ku}{Difference between H4 and H2K, in decibels.}
#'   \item{H42Kc}{Difference between H4 and H2K, in decibels. Corrected for the
#'   formant filter.}
#'   \item{H2KH5Ku}{Difference between H2K and H5K, in decibels.}
#'   \item{H2KH5Kc}{Difference between H2K and H5K, in decibels. Corrected for
#'   the formant filter.}
#'   \item{Energy}{Root mean square energy.}
#'   \item{HNR05}{Harmonics-to-noise ratio between 0-500 Hz.}
#'   \item{HNR15}{Harmonics-to-noise ratio between 0-1500 Hz.}
#'   \item{HNR25}{Harmonics-to-noise ratio between 0-2500 Hz.}
#'   \item{HNR35}{Harmonics-to-noise ratio between 0-3500 Hz.}
#'   \item{CPP}{Cepstral peak prominence, in decibels.}
#'   \item{SHR}{Amplitude ratio between subharmonics and harmonics (Sun 2002).}
#' }
#' @source \url{http://www.phonetics.ucla.edu/voiceproject/voice.html}
"rimes_voicesauce"
