% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{codas}
\alias{codas}
\title{Coda glottalization annotations}
\format{A data frame with 12,451 rows and 40 variables:
\describe{
  \item{track}{Name of the Buckeye Corpus file that contains this coda.}
  \item{coda_timestamp}{Timestamp of this coda in the Buckeye Corpus.}
  \item{word_timestamp}{Timestamp of the word in the Buckeye Corpus that
  contains this coda.}
  \item{filename}{Unique filename assigned to this token. Used for VoiceSauce
  and TextGrids.}
  \item{speaker}{Code-name in the Buckeye Corpus for the speaker who produced
  this coda.}
  \item{sex}{Sex of the speaker. F for female and M for male.}
  \item{age}{Age of the speaker. O for old (over 40) and Y for young (under
  30 or 40).}
  \item{word}{Word that contains this coda.}
  \item{coda_phonemic}{Dictionary transcription of the coda segment.}
  \item{coda_phonetic}{Close phonetic transcription of the coda segment, with
  Unicode transcriptions. Re-transcribed using the criteria described in
  Seyfarth & Garellek.}
  \item{coda_phonetic_uncorrected}{Close phonetic transcription of
  the coda segment, with pseudo-ARPABET transcriptions. Transcribed by the
  Buckeye Corpus annotators.}
  \item{coda_duration}{Duration of the coda, in seconds.}
  \item{vowel_phonemic}{Dictionary transcription of the nucleus vowel
  preceding this coda, with pseudo-ARPABET transcriptions.}
  \item{vowel_phonetic}{Close phonetic transcription of the nucleus vowel,
  with pseudo-ARPABET transcriptions. Transcribed by the Buckeye Corpus
  annotators.}
  \item{vowel_duration}{Duration of the nucleus vowel, in seconds.}
  \item{word_phonemic}{Dictionary transcription of the word that contains
  this coda, with pseudo-ARPABET transcriptions. Segments in the
  transcription are separated by underscores.}
  \item{word_phonetic}{close phonetic transcription of the word that contains
  this coda, with pseudo-ARPABET transcriptions. Transcribed by the Buckeye
  Corpus annotators. Segments in the transcription are separated by
  underscores.}
  \item{onset}{TRUE if the syllable that contains this coda has an onset.}
  \item{stress}{Lexical stress assigned to the syllable that contains this
  coda, roughly based on the CMU Pronouncing Dictionary distributed with
  NLTK. Stress for all function words words not in the CMU Pronouncing
  Dictionary were added manually.}
  \item{syllable_number}{1 if the coda is in the first syllable in the word,
  2 if the coda is in the second syllable in the word, etc.}
  \item{syllable_total}{Total number of syllables in the word.}
  \item{word_position}{'medial' if the coda is word-medial or 'final' if the
  coda is word-final.}
  \item{phrase_position}{'medial' if the word that contains this coda is
  phrase-medial, or 'final' if the word is phrase-final. Transcribed using
  the criteria described in Seyfarth & Garellek.}
  \item{utterance_position}{'medial' if the word that contains this coda is
  utterance-medial, or 'final' if the word is utterance-final. Words are
  considered to be utterance-final if they were phrase-final and were
  followed by a silence or other non-sound entry (IVER, LAUGH, NOISE, SIL,
  VOCNOIS, E_TRANS) in the original corpus annotations.}
  \item{following_phonemic}{Dictionary transcription of the segment
  following the coda, with pseudo-ARPABET transcriptions. Non-sound entries
  (IVER, LAUGH, NOISE, SIL, VOCNOISE, E_TRANS) are listed as 'none'.}
  \item{following_phonetic}{Close phonetic transcription of the segment
  following the coda, with pseudo-ARPABET transcriptions. Transcribed by
  the Buckeye Corpus annotators. Non-sound entries (IVER, LAUGH, NOISE, SIL,
  VOCNOIS, E_TRANS) are listed as 'none'.}
  \item{following_phonemic_uncorrected}{Dictionary transcription of the
  segment following the coda, with pseudo-ARPABET transcriptions.}
  \item{following_phonetic_uncorrected}{Close phonetic transcription of the
  segment following the coda, with pseudo-ARPABET transcriptions.
  Transcribed by the Buckeye Corpus annotators.}
  \item{preceding_word}{Word that precedes the word that contains this coda.}
  \item{following_word}{Word that follows the word that contains this coda.}
  \item{following_stress}{Lexical stress assigned to the syllable following
  the coda, roughly based on the CMU Pronouncing Dictionary distributed with
  NLTK. Stress for all function words words not in the CMU Pronouncing
  Dictionary were added manually.}
  \item{phrasal_creak}{TRUE if this coda occurs during a stretch of phrasal
  creak. Transcribed using the criteria described in Seyfarth & Garellek.}
  \item{phrasal_creak_uncorrected}{TRUE if this coda occurs during a stretch
  of speech that was marked as creaky voice by the Buckeye Corpus annotators,
  and the stretch of creaky voice was at least twice as long as the
  preceding nucleus vowel.}
  \item{speech_rate}{Speech rate of the utterance that contains this coda, in
  syllables per second. An utterance is defined as a stretch of speech
  delimited by pauses of 500 milliseconds or greater.}
  \item{closure_duration}{Duration of the closure portion of this coda.
  Hand-annotated but not all codas were annotated for closure duration.
  Codas that were not annotated for the closure duration are marked as NA.}
  \item{release}{TRUE if this coda was audibly and visibly released.
  Hand-annotated but not all codas were annotated for release. Codas that
  were not annotated for release are marked as NA.}
  \item{vowel_dB}{Mean intensity of the vowel, in decibels.}
  \item{burst_dB}{Mean intensity of the release burst, in decibels.}
  \item{alignment_corrected}{TRUE if the segmentation boundaries were altered
  from the boundaries provided by the Buckeye Corpus annotators}
  \item{comments}{Comments provided by research assistants during
  hand-annotation done with Seyfarth & Garellek.}
}}
\usage{
codas
}
\description{
Annotations for postvocalic /t/ and /p/ coda segments in the Buckeye Corpus,
including hand-corrected transcriptions for glottal replacement and phrasal
creak. One row per coda segment.
}
\details{
If you use this data in academic publications or presentations, please cite
the following publications:

Seyfarth, S. & Garellek, M. (2020). Physical and phonological causes of coda
/t/ glottalization in the mainstream American English of central Ohio.
Laboratory Phonology: Journal of the Association for Laboratory Phonology,
11(1), 24. DOI: http://doi.org/10.5334/labphon.213

Pitt, M.A., Dilley, L., Johnson, K., Kiesling, S., Raymond, W., Hume, E. and
Fosler-Lussier, E. (2007) Buckeye Corpus of Conversational Speech (2nd
release) [www.buckeyecorpus.osu.edu] Columbus, OH: Department of Psychology,
Ohio State University (Distributor).

The pseudo-ARPABET transcription system used for some of the columns is
described in the Buckeye Corpus manual.
}
\keyword{datasets}
