% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{vowels_voicesauce}
\alias{vowels_voicesauce}
\title{Summary VoiceSauce measurements for nucleus vowels followed by /t, p/ codas}
\format{A data frame with 41,001 rows and 51 variables:
\describe{
  \item{filename}{Unique filename assigned to this token. Used for VoiceSauce
  and TextGrids. This corresponds to the \code{filename} column in the
  \code{codas} dataframe.}
  \item{vowel_phonetic}{Close phonetic transcription of the nucleus vowel,
  with pseudo-ARPABET transcriptions. Transcribed by the Buckeye Corpus
  annotators. This corresponds to the \code{vowel_phonetic} column in the
  \code{codas} dataframe.}
  \item{vowel_duration_vs}{Duration of the nucleus vowel, in milliseconds.}
  \item{timepoint}{Timepoint of this measurement within the nucleus vowel. A
  1 means that this row contains the measurements for the first third of the
  vowel. A 2 means that this row contains the measurements for the middle
  third of the vowel. A 3 means that this row contains the measurements for
  the final third of the vowel, which is adjacent to the coda segment.}
  \item{strF0}{Fundamental frequency of the voice, in Hz, as measured by
  STRAIGHT (Kawahara et al., 1998).}
  \item{sF0}{Fundamental frequency of the voice, in Hz, as measured by
  Snack.}
  \item{shrF0}{Fundamental frequency of the voice, in Hz, as measured using
  the subharmonic-to-harmonic ratio method (Sun 2002).}
  \item{sF1}{Frequency of the first formant, in Hz, as measured by Snack.}
  \item{sB1}{Bandwidth of the first formant, in Hz, as measured by Snack.}
  \item{sF2}{Frequency of the second formant, in Hz, as measured by Snack.}
  \item{sB2}{Bandwidth of the second formant, in Hz, as measured by Snack.}
  \item{sF3}{Frequency of the third formant, in Hz, as measured by Snack.}
  \item{sB3}{Bandwidth of the third formant, in Hz, as measured by Snack.}
  \item{sF4}{Frequency of the fourth formant, in Hz, as measured by Snack.}
  \item{sB4}{Bandwidth of the fourth formant, in Hz, as measured by Snack.}
  \item{H1u}{Amplitude of the first harmonic of the voice.}
  \item{H1c}{Amplitude of the first harmonic of the voice. Corrected for the
  formant filter based on Iseli & Alwan (2004, 2006, 2007).}
  \item{H2u}{Amplitude of the second harmonic of the voice.}
  \item{H2c}{Amplitude of the second harmonic of the voice. Corrected for the
  formant filter.}
  \item{H4u}{Amplitude of the third harmonic of the voice.}
  \item{H4c}{Amplitude of the fourth harmonic of the voice. Corrected for the
  formant filter.}
  \item{H2Ku}{Amplitude of the harmonic closest to 2 kHz, in decibels.}
  \item{H2Kc}{Amplitude of the harmonic closest to 2 kHz, in decibels.
  Corrected for the formant filter.}
  \item{H5Ku}{Amplitude of the harmonic closest to 5 kHz, in decibels.}
  \item{A1u}{Amplitude of the harmonic closest to the first formant peak
  frequency, in decibels.}
  \item{A1c}{Amplitude of the harmonic closest to the first formant peak
  frequency, in decibels. Corrected for the formant filter.}
  \item{A2u}{Amplitude of the harmonic closest to the second formant peak
  frequency, in decibels.}
  \item{A2c}{Amplitude of the harmonic closest to the second formant peak
  frequency, in decibels. Corrected for the formant filter.}
  \item{A3u}{Amplitude of the harmonic closest to the third formant peak
  frequency, in decibels.}
  \item{A3c}{Amplitude of the harmonic closest to the third formant peak
  frequency, in decibels. Corrected for the formant filter.}
  \item{H1H2u}{Difference between H1 and H2, in decibels.}
  \item{H1H2c}{Difference between H1 and H2, in decibels. Corrected for the
  formant filter.}
  \item{H2H4u}{Difference between H2 and H4, in decibels.}
  \item{H2H4c}{Difference between H2 and H4, in decibels. Corrected for the
  formant filter.}
  \item{H1A1u}{Difference between H1 and A1, in decibels.}
  \item{H1A1c}{Difference between H1 and A1, in decibels. Corrected for the
  formant filter.}
  \item{H1A2u}{Difference between H1 and A2, in decibels.}
  \item{H1A2c}{Difference between H1 and A2, in decibels. Corrected for the
  formant filter.}
  \item{H1A3u}{Difference between H1 and A3, in decibels.}
  \item{H1A3c}{Difference between H1 and A3, in decibels. Corrected for the
  formant filter.}
  \item{H42Ku}{Difference between H4 and H2K, in decibels.}
  \item{H42Kc}{Difference between H4 and H2K, in decibels. Corrected for the
  formant filter.}
  \item{H2KH5Ku}{Difference between H2K and H5K, in decibels.}
  \item{H2KH5Kc}{Difference between H2K and H5K, in decibels. Corrected for
  the formant filter.}
  \item{Energy}{Root mean square energy.}
  \item{HNR05}{Harmonics-to-noise ratio between 0-500 Hz.}
  \item{HNR15}{Harmonics-to-noise ratio between 0-1500 Hz.}
  \item{HNR25}{Harmonics-to-noise ratio between 0-2500 Hz.}
  \item{HNR35}{Harmonics-to-noise ratio between 0-3500 Hz.}
  \item{CPP}{Cepstral peak prominence, in decibels.}
  \item{SHR}{Amplitude ratio between subharmonics and harmonics (Sun 2002).}
}}
\source{
\url{http://www.phonetics.ucla.edu/voiceproject/voice.html}
}
\usage{
vowels_voicesauce
}
\description{
This dataframe contains measurements at three timepoints within the vowel
preceding each coda in the \code{codas} dataframe, as measured by VoiceSauce.
}
\details{
If you use this data, please cite the papers listed in the description of
\code{codas} as well as the following papers:

Vicenik, C., Lin, S., Keating, P., & Shue, Y-.L. (2019). Online documentation
for VoiceSauce. Available at
http://www.phonetics.ucla.edu/voicesauce/documentation/index.html.

Shue, Y.-L., Keating, P., Vicenik, C., & Yu, K. (2011). VoiceSauce: A program
for voice analysis. Proceedings of ICPhS XVII, 1846--1849.
}
\keyword{datasets}
